==> owncloud-10.0.7.tgz: owncloud/lib/l10n/eo.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Ne skribeblas la dosierujo “config”!",
    "See %s" : "Vidi %s",
    "PHP %s or higher is required." : "PHP %s aŭ pli alta necesas.",
    "PHP with a version lower than %s is required." : "Necesas pli malalta eldono de PHP ol %s.",
    "Following databases are supported: %s" : "La jenan datumbazoj kongruas: %s",
    "The command line tool %s could not be found" : "La komandolinia ilo %s ne troviĝis",
    "The library %s is not available." : "La biblioteko %s ne haveblas.",
    "ownCloud %s or higher is required." : "ownCloud %s aŭ pli alta necesas.",
    "Unknown filetype" : "Ne konatas dosiertipo",
    "Invalid image" : "Ne validas bildo",
    "today" : "hodiaŭ",
    "yesterday" : "hieraŭ",
    "_%n day ago_::_%n days ago_" : ["antaŭ %n tago","antaŭ %n tagoj"],
    "last month" : "lastamonate",
    "last year" : "lastajare",
    "_%n year ago_::_%n years ago_" : ["antaŭ %n jaro","antaŭ %n jaroj"],
    "seconds ago" : "sekundoj antaŭe",
    "None" : "Nenio",
    "Username and password" : "Uzantonomo kaj pasvorto",
    "Username" : "Uzantonomo",
    "Password" : "Pasvorto",
    "Empty filename is not allowed" : "Malplena dosiernomo ne permesatas",
    "File name contains at least one invalid character" : "Dosiernomo enhavas almenaŭ unu nevalidan signon",
    "File name is too long" : "La dosiernomo tro longas",
    "App directory already exists" : "La dosierujo de la aplikaĵo jam ekzistas",
    "App does not provide an info.xml file" : "La aplikaĵo ne provizas dosieron info.xml",
    "App can't be installed because it is not compatible with this version of ownCloud" : "La aplikaĵo ne povas instaliĝi ĉar ĝi ne kongruas kun ĉi tiu eldono de ownCloud",
    "Apps" : "Aplikaĵoj",
    "General" : "Ĝenerala",
    "Storage" : "Konservejo",
    "Security" : "Sekuro",
    "Encryption" : "Ĉifrado",
    "Sharing" : "Kunhavigo",
    "Search" : "Serĉi",
    "Updates" : "Ĝisdatigoj",
    "%s enter the database username." : "%s enigu la uzantonomon de la datumbazo.",
    "%s enter the database name." : "%s enigu la nomon de la datumbazo.",
    "%s you may not use dots in the database name" : "%s vi ne povas uzi punktojn en la nomo de la datumbazo",
    "Oracle connection could not be established" : "Konekto al Oracle ne povas stariĝi",
    "Oracle username and/or password not valid" : "La uzantonomo de Oracle aŭ la pasvorto ne validas",
    "DB Error: \"%s\"" : "Datumbaza eraro: “%s”",
    "PostgreSQL username and/or password not valid" : "La uzantonomo de PostgreSQL aŭ la pasvorto ne validas",
    "Set an admin username." : "Starigi administran uzantonomon.",
    "Set an admin password." : "Starigi administran pasvorton.",
    "Can't create or write into the data directory %s" : "Ne kreeblas aŭ ne skribeblas la dosierujo de datumoj %s",
    "%s shared »%s« with you" : "%s kunhavigis “%s” kun vi",
    "%s via %s" : "%s per %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Kunhavigo de %s malsukcesis, ĉar la motoro ne permesas kunhavojn el tipo %i",
    "Sharing %s failed, because the file does not exist" : "Kunhavigo de %s malsukcesis, ĉar la dosiero ne ekzistas",
    "You are not allowed to share %s" : "Vi ne permesatas kunhavigi %s",
    "Sharing %s failed, because the user %s does not exist" : "Kunhavigo de %s malsukcesis, ĉar la uzanto %s ne ekzistas",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Kunhavigo de %s malsukcesis, ĉar la uzanto %s estas ano de neniu grupo, de kiu %s estas ano",
    "Sharing %s failed, because this item is already shared with %s" : "Kunhavigo de %s malsukcesis, ĉar la ero jam kunhavatas kun %s",
    "Sharing %s failed, because the group %s does not exist" : "Kunhavigo de %s malsukcesis, ĉar la grupo %s ne ekzistas",
    "Sharing %s failed, because %s is not a member of the group %s" : "Kunhavigo de %s malsukcesis, ĉar %s ne estas ano de la grupo %s",
    "Sharing %s failed, because sharing with links is not allowed" : "Kunhavo de %s malsukcesis, ĉar kunhavo per ligiloj ne permesatas",
    "Not allowed to create a federated share with the same user" : "Vi ne permesas krei federan kunhavon kun la sama uzanto",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Kunhavmotoro %s devas realigi la interfacon “OCP\\Share_Backend”",
    "Sharing backend %s not found" : "Kunhavmotoro %s ne troviĝas",
    "Sharing backend for %s not found" : "Kunhavmotoro por %s ne troviĝas",
    "Sharing %s failed, because resharing is not allowed" : "Kunhavigo de %s malsukcesis, ĉar rekunhavigo ne permesatas",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Kunhavigo de %s malsukcesis, ĉar la kunhavmotoro por %s ne povis trovi ĝian fonton",
    "Cannot increase permissions of %s" : "Ne eblas pliigi permesojn de %s",
    "Expiration date is in the past" : "Senvalidiĝa dato estintas",
    "Could not find category \"%s\"" : "Ne troviĝis kategorio “%s”",
    "A valid username must be provided" : "Valida uzantonomo devas proviziĝi",
    "Username contains whitespace at the beginning or at the end" : "Uzantonomo enhavas blankospacon eke aŭ maleke",
    "A valid password must be provided" : "Valida pasvorto devas proviziĝi",
    "The username is already being used" : "La uzantonomo jam uzatas",
    "Help" : "Helpo",
    "Settings" : "Agordo",
    "Users" : "Uzantoj",
    "web services under your control" : "TTT-servoj regataj de vi",
    "Can't read file" : "Ne legeblas dosiero",
    "Application is not enabled" : "La aplikaĵo ne estas kapabligita",
    "Authentication error" : "Aŭtentiga eraro",
    "Token expired. Please reload page." : "Ĵetono eksvalidiĝis. Bonvolu reŝargi la paĝon.",
    "Unknown user" : "Nekonata uzanto",
    "Cannot write into \"config\" directory" : "Ne skribeblas la dosierujo “config”",
    "Cannot write into \"apps\" directory" : "Ne skribeblas la dosierujo “apps”",
    "Please ask your server administrator to install the module." : "Bonvolu peti vian sistemadministranton, ke ĝi instalu la modulon.",
    "PHP module %s not installed." : "La PHP-modulo %s ne instalitas.",
    "Please ask your server administrator to restart the web server." : "Bonvolu peti viajn serviladministranton, ke ŝi/li reekfunkciigu la TTT-servilon.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 necesas",
    "Please upgrade your database version" : "Bonvolu ĝisdatigi la eldonon de via datumbazo",
    "Storage connection error. %s" : "Memorokonekta eraro. %s"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/lib/l10n/eo.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Ne skribeblas la dosierujo “config”!",
    "See %s" : "Vidi %s",
    "PHP %s or higher is required." : "PHP %s aŭ pli alta necesas.",
    "PHP with a version lower than %s is required." : "Necesas pli malalta eldono de PHP ol %s.",
    "Following databases are supported: %s" : "La jenan datumbazoj kongruas: %s",
    "The command line tool %s could not be found" : "La komandolinia ilo %s ne troviĝis",
    "The library %s is not available." : "La biblioteko %s ne haveblas.",
    "ownCloud %s or higher is required." : "ownCloud %s aŭ pli alta necesas.",
    "Unknown filetype" : "Ne konatas dosiertipo",
    "Invalid image" : "Ne validas bildo",
    "today" : "hodiaŭ",
    "yesterday" : "hieraŭ",
    "_%n day ago_::_%n days ago_" : ["antaŭ %n tago","antaŭ %n tagoj"],
    "last month" : "lastamonate",
    "last year" : "lastajare",
    "_%n year ago_::_%n years ago_" : ["antaŭ %n jaro","antaŭ %n jaroj"],
    "seconds ago" : "sekundoj antaŭe",
    "None" : "Nenio",
    "Username and password" : "Uzantonomo kaj pasvorto",
    "Username" : "Uzantonomo",
    "Password" : "Pasvorto",
    "Empty filename is not allowed" : "Malplena dosiernomo ne permesatas",
    "File name contains at least one invalid character" : "Dosiernomo enhavas almenaŭ unu nevalidan signon",
    "File name is too long" : "La dosiernomo tro longas",
    "App directory already exists" : "La dosierujo de la aplikaĵo jam ekzistas",
    "App does not provide an info.xml file" : "La aplikaĵo ne provizas dosieron info.xml",
    "App can't be installed because it is not compatible with this version of ownCloud" : "La aplikaĵo ne povas instaliĝi ĉar ĝi ne kongruas kun ĉi tiu eldono de ownCloud",
    "Apps" : "Aplikaĵoj",
    "General" : "Ĝenerala",
    "Storage" : "Konservejo",
    "Security" : "Sekuro",
    "Encryption" : "Ĉifrado",
    "Sharing" : "Kunhavigo",
    "Search" : "Serĉi",
    "Updates" : "Ĝisdatigoj",
    "%s enter the database username." : "%s enigu la uzantonomon de la datumbazo.",
    "%s enter the database name." : "%s enigu la nomon de la datumbazo.",
    "%s you may not use dots in the database name" : "%s vi ne povas uzi punktojn en la nomo de la datumbazo",
    "Oracle connection could not be established" : "Konekto al Oracle ne povas stariĝi",
    "Oracle username and/or password not valid" : "La uzantonomo de Oracle aŭ la pasvorto ne validas",
    "DB Error: \"%s\"" : "Datumbaza eraro: “%s”",
    "PostgreSQL username and/or password not valid" : "La uzantonomo de PostgreSQL aŭ la pasvorto ne validas",
    "Set an admin username." : "Starigi administran uzantonomon.",
    "Set an admin password." : "Starigi administran pasvorton.",
    "Can't create or write into the data directory %s" : "Ne kreeblas aŭ ne skribeblas la dosierujo de datumoj %s",
    "%s shared »%s« with you" : "%s kunhavigis “%s” kun vi",
    "%s via %s" : "%s per %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Kunhavigo de %s malsukcesis, ĉar la motoro ne permesas kunhavojn el tipo %i",
    "Sharing %s failed, because the file does not exist" : "Kunhavigo de %s malsukcesis, ĉar la dosiero ne ekzistas",
    "You are not allowed to share %s" : "Vi ne permesatas kunhavigi %s",
    "Sharing %s failed, because the user %s does not exist" : "Kunhavigo de %s malsukcesis, ĉar la uzanto %s ne ekzistas",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Kunhavigo de %s malsukcesis, ĉar la uzanto %s estas ano de neniu grupo, de kiu %s estas ano",
    "Sharing %s failed, because this item is already shared with %s" : "Kunhavigo de %s malsukcesis, ĉar la ero jam kunhavatas kun %s",
    "Sharing %s failed, because the group %s does not exist" : "Kunhavigo de %s malsukcesis, ĉar la grupo %s ne ekzistas",
    "Sharing %s failed, because %s is not a member of the group %s" : "Kunhavigo de %s malsukcesis, ĉar %s ne estas ano de la grupo %s",
    "Sharing %s failed, because sharing with links is not allowed" : "Kunhavo de %s malsukcesis, ĉar kunhavo per ligiloj ne permesatas",
    "Not allowed to create a federated share with the same user" : "Vi ne permesas krei federan kunhavon kun la sama uzanto",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Kunhavmotoro %s devas realigi la interfacon “OCP\\Share_Backend”",
    "Sharing backend %s not found" : "Kunhavmotoro %s ne troviĝas",
    "Sharing backend for %s not found" : "Kunhavmotoro por %s ne troviĝas",
    "Sharing %s failed, because resharing is not allowed" : "Kunhavigo de %s malsukcesis, ĉar rekunhavigo ne permesatas",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Kunhavigo de %s malsukcesis, ĉar la kunhavmotoro por %s ne povis trovi ĝian fonton",
    "Cannot increase permissions of %s" : "Ne eblas pliigi permesojn de %s",
    "Expiration date is in the past" : "Senvalidiĝa dato estintas",
    "Could not find category \"%s\"" : "Ne troviĝis kategorio “%s”",
    "A valid username must be provided" : "Valida uzantonomo devas proviziĝi",
    "Username contains whitespace at the beginning or at the end" : "Uzantonomo enhavas blankospacon eke aŭ maleke",
    "A valid password must be provided" : "Valida pasvorto devas proviziĝi",
    "The username is already being used" : "La uzantonomo jam uzatas",
    "Help" : "Helpo",
    "Settings" : "Agordo",
    "Users" : "Uzantoj",
    "web services under your control" : "TTT-servoj regataj de vi",
    "Can't read file" : "Ne legeblas dosiero",
    "Application is not enabled" : "La aplikaĵo ne estas kapabligita",
    "Authentication error" : "Aŭtentiga eraro",
    "Token expired. Please reload page." : "Ĵetono eksvalidiĝis. Bonvolu reŝargi la paĝon.",
    "Unknown user" : "Nekonata uzanto",
    "Cannot write into \"config\" directory" : "Ne skribeblas la dosierujo “config”",
    "Cannot write into \"apps\" directory" : "Ne skribeblas la dosierujo “apps”",
    "Please ask your server administrator to install the module." : "Bonvolu peti vian sistemadministranton, ke ĝi instalu la modulon.",
    "PHP module %s not installed." : "La PHP-modulo %s ne instalitas.",
    "Please ask your server administrator to restart the web server." : "Bonvolu peti viajn serviladministranton, ke ŝi/li reekfunkciigu la TTT-servilon.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 necesas",
    "Please upgrade your database version" : "Bonvolu ĝisdatigi la eldonon de via datumbazo",
    "Storage connection error. %s" : "Memorokonekta eraro. %s",
    "__language_name__" : "Esperanto"
},
"nplurals=2; plural=(n != 1);");
